summaryrefslogtreecommitdiffstats
path: root/src/gui/kdeext/QCanvasGroupableItem.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-09-06 20:59:29 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-09-06 20:59:29 +0000
commit11f31c37e5fa4889d9989f10272f44845449cb7b (patch)
tree4383da04a76c497950d957fc6120b0fd0d9082c2 /src/gui/kdeext/QCanvasGroupableItem.h
parent832eb69d571e8e518db45d0c0e6fbc0f00690209 (diff)
downloadrosegarden-11f31c37e5fa4889d9989f10272f44845449cb7b.tar.gz
rosegarden-11f31c37e5fa4889d9989f10272f44845449cb7b.zip
Initial TQt conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/rosegarden@1172292 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/gui/kdeext/QCanvasGroupableItem.h')
-rw-r--r--src/gui/kdeext/QCanvasGroupableItem.h74
1 files changed, 37 insertions, 37 deletions
diff --git a/src/gui/kdeext/QCanvasGroupableItem.h b/src/gui/kdeext/QCanvasGroupableItem.h
index 97d1917..1e54604 100644
--- a/src/gui/kdeext/QCanvasGroupableItem.h
+++ b/src/gui/kdeext/QCanvasGroupableItem.h
@@ -22,12 +22,12 @@
#ifndef QCANVASGROUPABLEITEM_H
#define QCANVASGROUPABLEITEM_H
-#include <qcanvas.h>
+#include <tqcanvas.h>
class QCanvasItemGroup;
/**
* This class is meant to be inherited by QCanvasItem children to make
* them groupable.
*
* On destruction, the item will remove itself from the group it's
@@ -50,7 +50,7 @@ public:
*
* @see QCanvasItemGroup#addItemWithRelativeCoords()
*/
- QCanvasGroupableItem(QCanvasItem*, QCanvasItemGroup*,
+ QCanvasGroupableItem(TQCanvasItem*, QCanvasItemGroup*,
bool withRelativeCoords = false);
virtual ~QCanvasGroupableItem();
@@ -61,8 +61,8 @@ public:
/// Returns the QCanvasItemGroup this groupable item belongs to
const QCanvasItemGroup* group() const { return m_group; }
- /// Returns the QCanvasItem which this groupable item wraps
- QCanvasItem *item() { return m_item; }
+ /// Returns the TQCanvasItem which this groupable item wraps
+ TQCanvasItem *item() { return m_item; }
/**
* Same as moveBy(), except that the move is done relative to the
@@ -83,40 +83,40 @@ private:
//--------------- Data members ---------------------------------
QCanvasItemGroup* m_group;
- QCanvasItem* m_item;
+ TQCanvasItem* m_item;
};
/**
* This class implements QCanvasItem groups
*
* An item group will keep its items in a fixed relative position when
* moved, just like in a drawing program where you can "bind" several
* items together so that they'll behave as a single item.
*
* Proper behavior requires collaboration from the QCanvasView,
* though. When about to move an item, the QCanvasView object should
* first check if it's not a groupable item, and if so fetch its
* QCanvasItemGroup and move it instead.
*/
class QCanvasItemGroup : public QCanvasItem
{
public:
- QCanvasItemGroup(QCanvas *);
+ QCanvasItemGroup(TQCanvas *);
virtual ~QCanvasItemGroup();
virtual void moveBy(double dx, double dy);
virtual void advance(int stage);
- virtual bool collidesWith(const QCanvasItem*) const;
- virtual void draw(QPainter&);
+ virtual bool collidesWith(const TQCanvasItem*) const;
+ virtual void draw(TQPainter&);
virtual void setVisible(bool yes);
virtual void setSelected(bool yes);
virtual void setEnabled(bool yes);
virtual void setActive(bool yes);
virtual int rtti() const;
- virtual QRect boundingRect() const;
- virtual QRect boundingRectAdvanced() const;
+ virtual TQRect boundingRect() const;
+ virtual TQRect boundingRectAdvanced() const;
/**
* Add a new item to this group.
@@ -125,7 +125,7 @@ public:
*
* @see addItemWithRelativeCoords()
*/
- virtual void addItem(QCanvasItem *);
+ virtual void addItem(TQCanvasItem *);
/**
* Add a new item to this group.
@@ -138,63 +138,63 @@ public:
*
* @see addItem()
*/
- virtual void addItemWithRelativeCoords(QCanvasItem *);
+ virtual void addItemWithRelativeCoords(TQCanvasItem *);
/**
* Remove the specified item from the group
*/
- virtual void removeItem(QCanvasItem*);
+ virtual void removeItem(TQCanvasItem*);
private:
- virtual bool collidesWith(const QCanvasSprite*,
- const QCanvasPolygonalItem*,
- const QCanvasRectangle*,
- const QCanvasEllipse*,
- const QCanvasText* ) const;
+ virtual bool collidesWith(const TQCanvasSprite*,
+ const TQCanvasPolygonalItem*,
+ const TQCanvasRectangle*,
+ const TQCanvasEllipse*,
+ const TQCanvasText* ) const;
protected:
//--------------- Data members ---------------------------------
- QCanvasItemList m_items;
+ TQCanvasItemList m_items;
};
/**
* A QCanvasLine which can be put in a QCanvasGroup
*/
-class QCanvasLineGroupable : public QCanvasLine, public QCanvasGroupableItem
+class QCanvasLineGroupable : public TQCanvasLine, public QCanvasGroupableItem
{
public:
- QCanvasLineGroupable(QCanvas *c, QCanvasItemGroup *g);
+ QCanvasLineGroupable(TQCanvas *c, QCanvasItemGroup *g);
};
/**
* A QCanvasRectangle which can be put in a QCanvasGroup
*/
-class QCanvasRectangleGroupable : public QCanvasRectangle, public QCanvasGroupableItem
+class QCanvasRectangleGroupable : public TQCanvasRectangle, public QCanvasGroupableItem
{
public:
- QCanvasRectangleGroupable(QCanvas *c, QCanvasItemGroup *g);
+ QCanvasRectangleGroupable(TQCanvas *c, QCanvasItemGroup *g);
};
/**
* A QCanvasText which can be put in a QCanvasGroup
*/
-class QCanvasTextGroupable : public QCanvasText, public QCanvasGroupableItem
+class QCanvasTextGroupable : public TQCanvasText, public QCanvasGroupableItem
{
public:
- QCanvasTextGroupable(QCanvas *c, QCanvasItemGroup *g);
- QCanvasTextGroupable(const QString&, QCanvas *c, QCanvasItemGroup *g);
+ QCanvasTextGroupable(TQCanvas *c, QCanvasItemGroup *g);
+ QCanvasTextGroupable(const TQString&, TQCanvas *c, QCanvasItemGroup *g);
};
/**
* A QCanvasSprite that can be put in a QCanvasGroup
*/
-class QCanvasSpriteGroupable : public QCanvasSprite, public QCanvasGroupableItem
+class QCanvasSpriteGroupable : public TQCanvasSprite, public QCanvasGroupableItem
{
public:
- QCanvasSpriteGroupable(QCanvasPixmapArray*,
- QCanvas*,
+ QCanvasSpriteGroupable(TQCanvasPixmapArray*,
+ TQCanvas*,
QCanvasItemGroup*);
};
@@ -22,12 +22,12 @@
class QCanvasItemGroup;
/**
- * This class is meant to be inherited by QCanvasItem children to make
+ * This class is meant to be inherited by TQCanvasItem children to make
* them groupable.
*
@@ -83,40 +83,40 @@ private:
};
/**
- * This class implements QCanvasItem groups
+ * This class implements TQCanvasItem groups
*
* An item group will keep its items in a fixed relative position when
@@ -83,40 +83,40 @@ private:
* items together so that they'll behave as a single item.
*
- * Proper behavior requires collaboration from the QCanvasView,
- * though. When about to move an item, the QCanvasView object should
+ * Proper behavior requires collaboration from the TQCanvasView,
+ * though. When about to move an item, the TQCanvasView object should
* first check if it's not a groupable item, and if so fetch its
* QCanvasItemGroup and move it instead.
@@ -138,63 +138,63 @@ public:
};
/**
- * A QCanvasLine which can be put in a QCanvasGroup
+ * A TQCanvasLine which can be put in a QCanvasGroup
*/
@@ -138,63 +138,63 @@ public:
};
/**
- * A QCanvasRectangle which can be put in a QCanvasGroup
+ * A TQCanvasRectangle which can be put in a QCanvasGroup
*/
@@ -138,63 +138,63 @@ public:
};
/**
- * A QCanvasText which can be put in a QCanvasGroup
+ * A TQCanvasText which can be put in a QCanvasGroup
*/
@@ -138,63 +138,63 @@ public:
};
/**
- * A QCanvasSprite that can be put in a QCanvasGroup
+ * A TQCanvasSprite that can be put in a QCanvasGroup
*/